# django-management-ui

Запускайте любые Django management-команды прямо из панели администратора. Без моделей, без миграций — просто установите и пользуйтесь.

Приложение анализирует argparse-определения ваших команд и динамически создаёт формы с подходящими виджетами: текстовые поля, чекбоксы, выпадающие списки, числовые поля, загрузка файлов для аргументов типа `Path`.

## Возможности

- Автоматическое обнаружение всех зарегистрированных management-команд
- Динамическая генерация форм по типам аргументов argparse
- Загрузка файлов с управлением жизненным циклом для аргументов `Path`
- Группировка: аргументы команды + сворачиваемые опции BaseCommand
- Захват вывода (stdout/stderr) с замером времени выполнения
- Доступ только для суперпользователей
- Отображается на главной странице Django Admin в списке приложений как раздел «Commands»

## Требования

- Python >= 3.11
- Django >= 4.2

## Лицензия

MIT
